@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2020, 2022 Oracle and its affiliates.
+# Copyright (c) 2020, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import geopandas
@@ -176,7 +176,7 @@ class PandasDataset(object):
                     out, f"calculating skew (<code>{column_name}</code>)..."
                 )
                 if len(self.df[column_name].dropna()) > 0:
-                    d[column_name] = self.df[column_name].dropna().skew().item(0)
+                    d[column_name] = self.df[column_name].dropna().skew()
                 else:
                     d[column_name] = np.nan
             df_skew = pd.DataFrame.from_dict(d, orient="index", columns=["skew"])
