@@ -442,3 +442,6 @@ class ModelDeploymentProperties(
 
         """
         return self.to_oci_model(data_science_models.UpdateModelDeploymentDetails)
+
+    def __eq__(self, other):
+        return self.to_dict() == other.to_dict()
