@@ -16,13 +16,7 @@ from typing import Dict
 import click
 import yaml
 
-# import conda_pack
-from io import StringIO
 from datetime import datetime
-import mmap
-import oci
-import types
-from tqdm import tqdm
 from docker import errors
 import ocifs
 
@@ -30,19 +24,23 @@ from ads.common.oci_client import OCIClientFactory
 from ads.common.auth import get_signer
 
 from ads.opctl.constants import (
-    DEFAULT_MANIFEST_VERSION,
     ML_JOB_GPU_IMAGE,
     ML_JOB_IMAGE,
     DEFAULT_IMAGE_HOME_DIR,
+    DEFAULT_IMAGE_CONDA_DIR,
+    DEFAULT_NOTEBOOK_SESSION_SPARK_CONF_DIR,
 )
 from ads.opctl import logger
-from ads.opctl.config.utils import _read_from_ini
-from ads.opctl.utils import _parse_conda_uri, _run_container, _get_docker_client
+from ads.opctl.config.utils import read_from_ini
+from ads.opctl.utils import (
+    parse_conda_uri,
+    run_container,
+    get_docker_client,
+    is_in_notebook_session,
+    run_command,
+)
 from ads.opctl.config.base import ConfigProcessor
 from ads.opctl.config.merger import ConfigMerger
-from ads.opctl.config.resolver import ConfigResolver
-from ads.opctl.config.utils import _read_from_ini
-from ads.opctl.config.validator import ConfigValidator
 from ads.opctl.conda.multipart_uploader import MultiPartUploader
 
 
@@ -61,7 +59,7 @@ def _check_job_image_exists(gpu: bool) -> None:
     else:
         image = ML_JOB_IMAGE
     try:
-        client = _get_docker_client()
+        client = get_docker_client()
         client.api.inspect_image(image)
     except errors.ImageNotFound:
         if gpu:
@@ -87,9 +85,7 @@ def _get_name(name: str, env_file: str) -> str:
 def create(**kwargs) -> str:
     p = ConfigProcessor().step(ConfigMerger, **kwargs)
     exec_config = p.config["execution"]
-    name = _get_name(
-        exec_config.get("name", None), exec_config.get("environment_file", None)
-    )
+    name = _get_name(exec_config.get("name"), exec_config.get("environment_file"))
     _create(
         name=name,
         version=exec_config["version"],
@@ -138,8 +134,6 @@ def _create(
         slug of the environment
     """
 
-    _check_job_image_exists(gpu)
-
     if not os.path.exists(env_file):
         raise FileNotFoundError(f"Environment file {env_file} is not found.")
 
@@ -181,29 +175,36 @@ def _create(
     manifest["manifest"]["manifest_version"] = "1.0"
 
     logger.info(f"Creating conda environment {slug}")
-    docker_pack_folder_path = os.path.join(DEFAULT_IMAGE_HOME_DIR, slug)
-    docker_env_file_path = os.path.join(
-        DEFAULT_IMAGE_HOME_DIR, os.path.basename(env_file)
-    )
-
-    create_command = f"conda env create --prefix {docker_pack_folder_path} --file {docker_env_file_path}"
-
-    volumes = {
-        pack_folder_path: {"bind": docker_pack_folder_path},
-        os.path.abspath(os.path.expanduser(env_file)): {"bind": docker_env_file_path},
-    }
-    if gpu:
-        image = ML_JOB_GPU_IMAGE
+    if is_in_notebook_session():
+        command = f"conda env create --prefix {pack_folder_path} --file {os.path.abspath(os.path.expanduser(env_file))}"
+        run_command(command, shell=True)
     else:
-        image = ML_JOB_IMAGE
-    try:
-        _run_container(
-            image=image, bind_volumes=volumes, env_vars={}, command=create_command
+        _check_job_image_exists(gpu)
+        docker_pack_folder_path = os.path.join(DEFAULT_IMAGE_HOME_DIR, slug)
+        docker_env_file_path = os.path.join(
+            DEFAULT_IMAGE_HOME_DIR, os.path.basename(env_file)
         )
-    except Exception:
-        if os.path.exists(pack_folder_path):
-            shutil.rmtree(pack_folder_path)
-        raise RuntimeError(f"Could not create environment {slug}.")
+
+        create_command = f"conda env create --prefix {docker_pack_folder_path} --file {docker_env_file_path}"
+
+        volumes = {
+            pack_folder_path: {"bind": docker_pack_folder_path},
+            os.path.abspath(os.path.expanduser(env_file)): {
+                "bind": docker_env_file_path
+            },
+        }
+        if gpu:
+            image = ML_JOB_GPU_IMAGE
+        else:
+            image = ML_JOB_IMAGE
+        try:
+            run_container(
+                image=image, bind_volumes=volumes, env_vars={}, command=create_command
+            )
+        except Exception:
+            if os.path.exists(pack_folder_path):
+                shutil.rmtree(pack_folder_path)
+            raise RuntimeError(f"Could not create environment {slug}.")
 
     conda_dep = None
     with open(env_file) as mfile:
@@ -217,7 +218,9 @@ def _create(
     return slug
 
 
-def _fetch_pack_path(slug, conda_pack_os_prefix, oci_config, oci_profile):
+def _fetch_pack_path(
+    slug: str, conda_pack_os_prefix: str, oci_config: str, oci_profile: str
+) -> str:
     oci_auth = get_signer(oci_config, oci_profile)
     fs = ocifs.OCIFileSystem(**oci_auth)
     fnames = fs.ls(conda_pack_os_prefix, detail=True, refresh=True)
@@ -234,18 +237,18 @@ def _fetch_pack_path(slug, conda_pack_os_prefix, oci_config, oci_profile):
 def install(**kwargs) -> None:
     p = ConfigProcessor().step(ConfigMerger, **kwargs)
     exec_config = p.config["execution"]
-    if exec_config.get("slug", None) and exec_config.get("conda_pack_os_prefix", None):
+    if exec_config.get("slug") and exec_config.get("conda_pack_os_prefix"):
         conda_uri = _fetch_pack_path(
             exec_config["slug"],
             exec_config["conda_pack_os_prefix"],
-            exec_config["oci_config"],
-            exec_config["oci_profile"],
+            exec_config.get("oci_config"),
+            exec_config.get("oci_profile"),
         )
         if not conda_uri:
             raise FileNotFoundError(
                 f"{exec_config['slug']} not found under {exec_config['conda_pack_os_prefix']}"
             )
-    elif exec_config.get("conda_uri", None):
+    elif exec_config.get("conda_uri"):
         conda_uri = exec_config["conda_uri"]
     else:
         raise ValueError(
@@ -254,8 +257,8 @@ def install(**kwargs) -> None:
     _install(
         conda_uri,
         os.path.abspath(os.path.expanduser(exec_config["conda_pack_folder"])),
-        os.path.abspath(os.path.expanduser(exec_config["oci_config"])),
-        exec_config["oci_profile"],
+        exec_config.get("oci_config"),
+        exec_config.get("oci_profile"),
         overwrite=exec_config.get("overwrite", False),
         debug=kwargs.get("debug", False),
     )
@@ -264,8 +267,8 @@ def install(**kwargs) -> None:
 def _install(
     conda_uri: str,
     conda_pack_folder: str,
-    oci_config: str,
-    oci_profile: str,
+    oci_config: str = None,
+    oci_profile: str = None,
     overwrite: bool = False,
     debug: bool = False,
 ) -> None:
@@ -286,21 +289,18 @@ def _install(
         whether to overwrite existing pack
     debug: bool
         whether to turn on debug mode
-    quiet: bool
-        whether to suppress user prompt
     Returns
     -------
     None
     """
-    if oci_config and oci_profile:
-        parser = _read_from_ini(os.path.expanduser(oci_config))
-        if oci_profile not in parser:
-            raise ValueError(f"PROFILE {oci_profile} not found in {oci_config}.")
-    ns, bucket, path, slug = _parse_conda_uri(conda_uri)
+    ns, bucket, path, slug = parse_conda_uri(conda_uri)
     os.makedirs(conda_pack_folder, exist_ok=True)
     pack_path = os.path.join(os.path.expanduser(conda_pack_folder), slug + ".tar.gz")
     pack_folder_path = os.path.join(os.path.expanduser(conda_pack_folder), slug)
 
+    if not is_in_notebook_session():
+        _check_job_image_exists(gpu=False)
+
     while os.path.exists(pack_folder_path):
         if overwrite:
             break
@@ -321,24 +321,46 @@ def _install(
                     os.path.expanduser(conda_pack_folder), slug
                 )
 
-    download_command = [
-        "oci",
-        "os",
-        "object",
-        "get",
-        "--name",
-        f"{path}",
-        "-bn",
-        bucket,
-        "-ns",
-        ns,
-        "--file",
-        pack_path,
-        "--profile",
-        oci_profile,
-        "--config-file",
-        oci_config,
-    ]
+    if oci_config is None or oci_profile is None:
+        download_command = [
+            "oci",
+            "os",
+            "object",
+            "get",
+            "--name",
+            f"{path}",
+            "-bn",
+            bucket,
+            "-ns",
+            ns,
+            "--file",
+            pack_path,
+            "--auth",
+            "resource_principal",
+        ]
+    else:
+        oci_config = os.path.abspath(os.path.expanduser(oci_config))
+        parser = read_from_ini(os.path.expanduser(oci_config))
+        if oci_profile not in parser:
+            raise ValueError(f"PROFILE {oci_profile} not found in {oci_config}.")
+        download_command = [
+            "oci",
+            "os",
+            "object",
+            "get",
+            "--name",
+            f"{path}",
+            "-bn",
+            bucket,
+            "-ns",
+            ns,
+            "--file",
+            pack_path,
+            "--profile",
+            oci_profile,
+            "--config-file",
+            oci_config,
+        ]
     if debug:
         download_command.append("-d")
         print(" ".join([shlex.quote(c) for c in download_command]))
@@ -369,26 +391,56 @@ def _install(
     # See https://conda.github.io/conda-pack/#commandline-usage
     unpack_script = os.path.join(pack_folder_path, "bin", "conda-unpack")
     if os.path.exists(unpack_script):
-        volumes = {
-            pack_folder_path: {"bind": os.path.join(DEFAULT_IMAGE_HOME_DIR, slug)}
-        }
-        try:
-            _run_container(
-                image=ML_JOB_IMAGE,
-                bind_volumes=volumes,
-                env_vars={},
-                command=os.path.join(DEFAULT_IMAGE_HOME_DIR, slug, "bin/conda-unpack"),
-            )
-        except Exception:
-            raise RuntimeError(f"Error unpacking environment {slug}.")
-    # There will be no unpack script if user build the pack with --dest-prefix argument.
-    # if os.path.exists(unpack_script):
-    #     print("Running conda unpack")
-    #     process = subprocess.Popen([unpack_script])
-    #     process.communicate()
-    #     if process.returncode != 0:
-    #         raise Exception(f"Error running {unpack_script}")
+        if is_in_notebook_session():
+            run_command(unpack_script)
+        else:
+            volumes = {
+                pack_folder_path: {"bind": os.path.join(DEFAULT_IMAGE_HOME_DIR, slug)}
+            }
+            try:
+                run_container(
+                    image=ML_JOB_IMAGE,
+                    bind_volumes=volumes,
+                    env_vars={},
+                    command=os.path.join(
+                        DEFAULT_IMAGE_HOME_DIR, slug, "bin/conda-unpack"
+                    ),
+                )
+            except Exception:
+                raise RuntimeError(f"Error unpacking environment {slug}.")
+        if os.path.exists(os.path.join(pack_folder_path, "spark-defaults.conf")):
+            if is_in_notebook_session():
+                if not os.path.exists(DEFAULT_NOTEBOOK_SESSION_SPARK_CONF_DIR):
+                    os.makedirs(DEFAULT_NOTEBOOK_SESSION_SPARK_CONF_DIR)
+                    shutil.copy(
+                        os.path.join(pack_folder_path, "spark-defaults.conf"),
+                        DEFAULT_NOTEBOOK_SESSION_SPARK_CONF_DIR,
+                    )
+                    for file in os.listdir(pack_folder_path):
+                        if os.path.splitext(file)[1] == ".jar":
+                            shutil.copy(
+                                os.path.join(pack_folder_path, file),
+                                DEFAULT_NOTEBOOK_SESSION_SPARK_CONF_DIR,
+                            )
+            else:
+                with open(os.path.join(pack_folder_path, "spark-defaults.conf")) as f:
+                    confs = f.read()
+                confs = confs.replace(
+                    DEFAULT_NOTEBOOK_SESSION_SPARK_CONF_DIR,
+                    os.path.join(DEFAULT_IMAGE_CONDA_DIR, slug),
+                )
+                with open(
+                    os.path.join(pack_folder_path, "spark-defaults.conf"), "w"
+                ) as f:
+                    f.write(confs)
+
     os.remove(pack_path)
+    manifest_path = glob.glob(os.path.join(pack_folder_path, "*_manifest.yaml"))[0]
+    with open(manifest_path) as f:
+        env = yaml.safe_load(f.read())
+    env["manifest"]["pack_uri"] = conda_uri
+    with open(manifest_path, "w") as f:
+        yaml.safe_dump(env, f)
     print(f"{slug} set up at {pack_folder_path}.")
 
 
@@ -396,9 +448,7 @@ def publish(**kwargs) -> None:
     p = ConfigProcessor().step(ConfigMerger, **kwargs)
     exec_config = p.config["execution"]
     if exec_config.get("environment_file", None):
-        name = _get_name(
-            exec_config.get("name", None), exec_config.get("environment_file", None)
-        )
+        name = _get_name(exec_config.get("name"), exec_config.get("environment_file"))
         slug = _create(
             name=name,
             version=exec_config["version"],
@@ -408,10 +458,10 @@ def publish(**kwargs) -> None:
             overwrite=exec_config["overwrite"],
         )
     else:
-        slug = exec_config.get("slug", None)
+        slug = exec_config.get("slug")
     if not slug:
         raise ValueError("Please specify slug of the conda pack via `--slug`.")
-    if not exec_config.get("conda_pack_os_prefix", None):
+    if not exec_config.get("conda_pack_os_prefix"):
         raise ValueError(
             "Please specify object storage path to save conda pack either via `ads opctl configure` or `--conda-pack-os-prefix`."
         )
@@ -419,8 +469,8 @@ def publish(**kwargs) -> None:
         conda_slug=slug,
         conda_uri_prefix=exec_config["conda_pack_os_prefix"],
         conda_pack_folder=exec_config["conda_pack_folder"],
-        oci_config=exec_config["oci_config"],
-        oci_profile=exec_config["oci_profile"],
+        oci_config=exec_config.get("oci_config"),
+        oci_profile=exec_config.get("oci_profile"),
         overwrite=exec_config["overwrite"],
     )
 
@@ -465,7 +515,7 @@ def _publish(
     RuntimeError
         Pack file not found
     """
-    ns, bucket, prefix, _ = _parse_conda_uri(conda_uri_prefix)
+    ns, bucket, prefix, _ = parse_conda_uri(conda_uri_prefix)
 
     # ======= check if conda pack and manifest exists ==============
     pack_folder_path = os.path.abspath(
@@ -507,21 +557,29 @@ def _publish(
                 publish_slug = "_".join(ans.lower().split(" "))
 
     pack_script = os.path.join(os.path.dirname(os.path.abspath(__file__)), "pack.py")
-    volumes = {
-        pack_folder_path: {"bind": os.path.join(DEFAULT_IMAGE_HOME_DIR, conda_slug)},
-        pack_script: {"bind": os.path.join(DEFAULT_IMAGE_HOME_DIR, "pack.py")},
-    }
-    command = f"python {os.path.join(DEFAULT_IMAGE_HOME_DIR, 'pack.py')} {os.path.join(DEFAULT_IMAGE_HOME_DIR, conda_slug)}"
-    gpu = env["manifest"]["arch_type"] == "GPU"
-    _check_job_image_exists(gpu)
-    if gpu:
-        image = ML_JOB_GPU_IMAGE
+    if is_in_notebook_session():
+        command = f"python {pack_script} {pack_folder_path}"
+        run_command(command, shell=True)
     else:
-        image = ML_JOB_IMAGE
-    try:
-        _run_container(image=image, bind_volumes=volumes, env_vars={}, command=command)
-    except Exception:
-        raise RuntimeError(f"Could not pack environment {conda_slug}.")
+        volumes = {
+            pack_folder_path: {
+                "bind": os.path.join(DEFAULT_IMAGE_HOME_DIR, conda_slug)
+            },
+            pack_script: {"bind": os.path.join(DEFAULT_IMAGE_HOME_DIR, "pack.py")},
+        }
+        command = f"python {os.path.join(DEFAULT_IMAGE_HOME_DIR, 'pack.py')} {os.path.join(DEFAULT_IMAGE_HOME_DIR, conda_slug)}"
+        gpu = env["manifest"]["arch_type"] == "GPU"
+        _check_job_image_exists(gpu)
+        if gpu:
+            image = ML_JOB_GPU_IMAGE
+        else:
+            image = ML_JOB_IMAGE
+        try:
+            run_container(
+                image=image, bind_volumes=volumes, env_vars={}, command=command
+            )
+        except Exception:
+            raise RuntimeError(f"Could not pack environment {conda_slug}.")
 
     pack_file = os.path.join(pack_folder_path, f"{conda_slug}.tar.gz")
     if not os.path.exists(pack_file):
@@ -536,7 +594,7 @@ def _publish(
         "%a, %b %d, %Y, %H:%M:%S %Z UTC"
     )
     manifest["size_mb"] = pack_size
-    ns, bucket, prefix, _ = _parse_conda_uri(conda_uri_prefix)
+    ns, bucket, prefix, _ = parse_conda_uri(conda_uri_prefix)
 
     pack_uri = os.path.join(
         conda_uri_prefix,
@@ -552,6 +610,9 @@ def _publish(
         str(manifest["version"]),
         publish_slug,
     )
+    manifest["pack_uri"] = pack_uri
+    with open(manifest_location, "w") as f:
+        yaml.safe_dump(env, f)
     if pack_size > 100:
         MultiPartUploader(pack_file, pack_uri, 10, oci_config, oci_profile).upload(
             manifest
